# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/orderbookl2_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'sdk/stream/orderbookl2_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a\"sdk/core/instrument_criteria.proto\"W\n\x1aStreamOrderBookL2RequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\"\x87\x01\n StreamOrderBookL2ReplayRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12(\n\x08interval\x18\x02 \x01(\x0b\x32\x16.kaikosdk.DataIntervalB\x8d\x01\n#com.kaiko.sdk.stream.orderbookl2_v1P\x01ZFgithub.com/kaikodata/kaiko-go-sdk/stream/orderbookl2_v1;orderbookl2_v1\xaa\x02\x1bKaikoSdk.Stream.OrderBookL2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.orderbookl2_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.kaiko.sdk.stream.orderbookl2_v1P\001ZFgithub.com/kaikodata/kaiko-go-sdk/stream/orderbookl2_v1;orderbookl2_v1\252\002\033KaikoSdk.Stream.OrderBookL2'
  _globals['_STREAMORDERBOOKL2REQUESTV1']._serialized_start=119
  _globals['_STREAMORDERBOOKL2REQUESTV1']._serialized_end=206
  _globals['_STREAMORDERBOOKL2REPLAYREQUESTV1']._serialized_start=209
  _globals['_STREAMORDERBOOKL2REPLAYREQUESTV1']._serialized_end=344
# @@protoc_insertion_point(module_scope)
